@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2019 Google LLC
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,13 +16,27 @@
 
 
 from __future__ import absolute_import
+import sys
+import warnings
 
 from google.cloud.translate_v3 import types
 from google.cloud.translate_v3.gapic import translation_service_client
 
 
+if sys.version_info[:2] == (2, 7):
+    message = (
+        "A future version of this library will drop support for Python 2.7. "
+        "More details about Python 2 support for Google Cloud Client Libraries "
+        "can be found at https://cloud.google.com/python/docs/python2-sunset/"
+    )
+    warnings.warn(message, DeprecationWarning)
+
+
 class TranslationServiceClient(translation_service_client.TranslationServiceClient):
     __doc__ = translation_service_client.TranslationServiceClient.__doc__
 
 
-__all__ = ("types", "TranslationServiceClient")
+__all__ = (
+    "types",
+    "TranslationServiceClient",
+)
